@@ -128,7 +128,6 @@ class Users(object):
 		# set defaults.
 		if name == None: name = user.display_name
 		if email == None: email = user.email
-		if password == None: password = user.password
 		if phone_number == None: phone_number = user.phone_number
 		if photo_url == None: photo_url = user.photo_url
 		if email_verified == None: email_verified = user.email_verified
@@ -193,7 +192,7 @@ class Users(object):
 		if success:
 			return r3sponse.success_response("You are signed in.", {"uid":uid})
 		else:
-			return r3sponse.error_response("You are not signed in., error: {error}")
+			return r3sponse.error_response(f"You are not signed in, error: {error}")
 
 		#
 
